==> ansible_2.7.7.1.orig.tar.xz: ansible-2.7.7.1/test/units/modules/network/f5/test_bigip_profile_oneconnect.py <==
# -*- coding: utf-8 -*-
#
# Copyright: (c) 2017, F5 Networks Inc.
# GNU General Public License v3.0 (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import (absolute_import, division, print_function)
__metaclass__ = type

import os
import json
import pytest
import sys

from nose.plugins.skip import SkipTest
if sys.version_info < (2, 7):
    raise SkipTest("F5 Ansible modules require Python >= 2.7")

from ansible.compat.tests import unittest
from ansible.compat.tests.mock import Mock
from ansible.compat.tests.mock import patch
from ansible.module_utils.basic import AnsibleModule

try:
    from library.modules.bigip_profile_oneconnect import ApiParameters
    from library.modules.bigip_profile_oneconnect import ModuleParameters
    from library.modules.bigip_profile_oneconnect import ModuleManager
    from library.modules.bigip_profile_oneconnect import ArgumentSpec
    from library.module_utils.network.f5.common import F5ModuleError
    from library.module_utils.network.f5.common import iControlUnexpectedHTTPError
    from test.unit.modules.utils import set_module_args
except ImportError:
    try:
        from ansible.modules.network.f5.bigip_profile_oneconnect import ApiParameters
        from ansible.modules.network.f5.bigip_profile_oneconnect import ModuleParameters
        from ansible.modules.network.f5.bigip_profile_oneconnect import ModuleManager
        from ansible.modules.network.f5.bigip_profile_oneconnect import ArgumentSpec
        from ansible.module_utils.network.f5.common import F5ModuleError
        from ansible.module_utils.network.f5.common import iControlUnexpectedHTTPError
        from units.modules.utils import set_module_args
    except ImportError:
        raise SkipTest("F5 Ansible modules require the f5-sdk Python library")

fixture_path = os.path.join(os.path.dirname(__file__), 'fixtures')
fixture_data = {}


def load_fixture(name):
    path = os.path.join(fixture_path, name)

    if path in fixture_data:
        return fixture_data[path]

    with open(path) as f:
        data = f.read()

    try:
        data = json.loads(data)
    except Exception:
        pass

    fixture_data[path] = data
    return data


class TestParameters(unittest.TestCase):
    def test_module_parameters(self):
        args = dict(
            name='foo',
            parent='bar',
            maximum_size=100,
            maximum_age=200,
            maximum_reuse=300,
            idle_timeout_override=20,
            limit_type='strict'
        )

        p = ModuleParameters(params=args)
        assert p.name == 'foo'
        assert p.parent == '/Common/bar'
        assert p.maximum_size == 100
        assert p.maximum_age == 200
        assert p.maximum_reuse == 300
        assert p.idle_timeout_override == 20
        assert p.limit_type == 'strict'

    def test_api_parameters(self):
        args = load_fixture('load_ltm_profile_oneconnect_1.json')
        p = ApiParameters(params=args)
        assert p.name == 'oneconnect'
        assert p.maximum_reuse == 1000


class TestManager(unittest.TestCase):

    def setUp(self):
        self.spec = ArgumentSpec()

    def test_create(self, *args):
        # Configure the arguments that would be sent to the Ansible module
        set_module_args(dict(
            name='foo',
            parent='bar',
            maximum_reuse=1000,
            password='password',
            server='localhost',
            user='admin'
        ))

        module = AnsibleModule(
            argument_spec=self.spec.argument_spec,
            supports_check_mode=self.spec.supports_check_mode
        )
        mm = ModuleManager(module=module)

        # Override methods to force specific logic in the module to happen
        mm.exists = Mock(return_value=False)
        mm.create_on_device = Mock(return_value=True)

        results = mm.exec_module()

        assert results['changed'] is True
        assert results['maximum_reuse'] == 1000

==> ansible_2.9.6+dfsg.orig.tar.xz: ansible-2.9.6/test/units/modules/network/f5/test_bigip_profile_oneconnect.py <==
# -*- coding: utf-8 -*-
#
# Copyright: (c) 2017, F5 Networks Inc.
# GNU General Public License v3.0 (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import (absolute_import, division, print_function)
__metaclass__ = type

import os
import json
import pytest
import sys

if sys.version_info < (2, 7):
    pytestmark = pytest.mark.skip("F5 Ansible modules require Python >= 2.7")

from ansible.module_utils.basic import AnsibleModule

try:
    from library.modules.bigip_profile_oneconnect import ApiParameters
    from library.modules.bigip_profile_oneconnect import ModuleParameters
    from library.modules.bigip_profile_oneconnect import ModuleManager
    from library.modules.bigip_profile_oneconnect import ArgumentSpec

    # In Ansible 2.8, Ansible changed import paths.
    from test.units.compat import unittest
    from test.units.compat.mock import Mock

    from test.units.modules.utils import set_module_args
except ImportError:
    from ansible.modules.network.f5.bigip_profile_oneconnect import ApiParameters
    from ansible.modules.network.f5.bigip_profile_oneconnect import ModuleParameters
    from ansible.modules.network.f5.bigip_profile_oneconnect import ModuleManager
    from ansible.modules.network.f5.bigip_profile_oneconnect import ArgumentSpec

    # Ansible 2.8 imports
    from units.compat import unittest
    from units.compat.mock import Mock

    from units.modules.utils import set_module_args


fixture_path = os.path.join(os.path.dirname(__file__), 'fixtures')
fixture_data = {}


def load_fixture(name):
    path = os.path.join(fixture_path, name)

    if path in fixture_data:
        return fixture_data[path]

    with open(path) as f:
        data = f.read()

    try:
        data = json.loads(data)
    except Exception:
        pass

    fixture_data[path] = data
    return data


class TestParameters(unittest.TestCase):
    def test_module_parameters(self):
        args = dict(
            name='foo',
            parent='bar',
            maximum_size=100,
            maximum_age=200,
            maximum_reuse=300,
            idle_timeout_override=20,
            limit_type='strict'
        )

        p = ModuleParameters(params=args)
        assert p.name == 'foo'
        assert p.parent == '/Common/bar'
        assert p.maximum_size == 100
        assert p.maximum_age == 200
        assert p.maximum_reuse == 300
        assert p.idle_timeout_override == 20
        assert p.limit_type == 'strict'

    def test_api_parameters(self):
        args = load_fixture('load_ltm_profile_oneconnect_1.json')
        p = ApiParameters(params=args)
        assert p.name == 'oneconnect'
        assert p.maximum_reuse == 1000


class TestManager(unittest.TestCase):

    def setUp(self):
        self.spec = ArgumentSpec()

    def test_create(self, *args):
        # Configure the arguments that would be sent to the Ansible module
        set_module_args(dict(
            name='foo',
            parent='bar',
            maximum_reuse=1000,
            provider=dict(
                server='localhost',
                password='password',
                user='admin'
            )
        ))

        module = AnsibleModule(
            argument_spec=self.spec.argument_spec,
            supports_check_mode=self.spec.supports_check_mode
        )
        mm = ModuleManager(module=module)

        # Override methods to force specific logic in the module to happen
        mm.exists = Mock(return_value=False)
        mm.create_on_device = Mock(return_value=True)

        results = mm.exec_module()

        assert results['changed'] is True
        assert results['maximum_reuse'] == 1000
